@@ -2,11 +2,8 @@
 set -e
 set -x
 
-#clone test firmware
-if [ "$CI_NETWORK" = "true" ]; then
-	./contrib/ci/get_test_firmware.sh
-	export G_TEST_SRCDIR=`pwd`/fwupd-test-firmware/installed-tests
-fi
+#clone test firmware if necessary
+. ./contrib/ci/get_test_firmware.sh
 
 #build
 rm -rf build
@@ -20,7 +17,7 @@ meson .. \
 	-Dplugin_synaptics_mst=true \
 	-Dplugin_flashrom=true \
 	-Dintrospection=true \
-	-Dgtkdoc=true \
+	-Ddocs=gtkdoc \
 	-Dpkcs7=false \
 	-Dman=true
 ninja-build -v
