@@ -26,7 +26,7 @@ VERSION=`git describe | sed 's/-/+r/;s/-/+/'`
 rm -rf build/
 mkdir -p build
 shopt -s extglob
-cp -lR !(build|dist) build/
+cp -lR !(build|dist|venv) build/
 pushd build
 mv contrib/debian .
 sed s/quilt/native/ debian/source/format -i
@@ -36,17 +36,14 @@ sed s/quilt/native/ debian/source/format -i
 #check if we have all deps available
 #if some are missing, we're going to use subproject instead and
 #packaging CI will fail
-./contrib/ci/generate_dependencies.py  | xargs apt install -y || true
+./contrib/ci/fwupd_setup_helpers.py install-dependencies -o debian --yes || true
 if ! dpkg-checkbuilddeps; then
 	./contrib/ci/ubuntu.sh
 	exit 0
 fi
 
-#clone test firmware
-if [ "$CI_NETWORK" = "true" ]; then
-	./contrib/ci/get_test_firmware.sh
-	export G_TEST_SRCDIR=`pwd`/fwupd-test-firmware/installed-tests
-fi
+#clone test firmware if necessary
+. ./contrib/ci/get_test_firmware.sh
 
 #disable unit tests if fwupd is already installed (may cause problems)
 if [ -x /usr/lib/fwupd/fwupd ]; then
@@ -79,9 +76,13 @@ if [ ! -f /.dockerenv ]; then
 fi
 
 #test the packages install
-PACKAGES=$(ls ../*.deb | grep -v 'fwupd-tests\|dbgsym')
+PACKAGES=$(find .. -type f -name "*.deb" | grep -v 'fwupd-tests\|dbgsym')
 dpkg -i $PACKAGES
 
+# copy in more non-generated data
+mkdir -p /usr/share/installed-tests/fwupd
+cp fwupd-test-firmware/installed-tests/* /usr/share/installed-tests/fwupd/ -LRv
+
 # run the installed tests
 if [ "$CI" = "true" ]; then
 	dpkg -i ../fwupd-tests*.deb
