@@ -5,8 +5,10 @@ set -x
 #get any missing deps from the container
 ./contrib/ci/fwupd_setup_helpers.py install-dependencies --yes -o fedora
 
+# disable the safe directory feature
+git config --global safe.directory "*"
+
 #generate a tarball
-git config tar.tar.xz.command "xz -c"
 mkdir -p build && pushd build
 rm -rf *
 
