@@ -13,7 +13,7 @@ import shutil
 import tempfile
 import zipfile
 
-TAG = b'#\x00'
+TAG = b"#\x00"
 
 
 def parse_args():
@@ -23,19 +23,19 @@ def parse_args():
     parser.add_argument("--directory", help="Directory to extract to")
     parser.add_argument(
         "--cleanup",
-        action='store_true',
+        action="store_true",
         help="Remove tools when done with installation",
     )
     parser.add_argument(
-        "--verbose", action='store_true', help="Run the tool in verbose mode"
+        "--verbose", action="store_true", help="Run the tool in verbose mode"
     )
     parser.add_argument(
         "--allow-reinstall",
-        action='store_true',
+        action="store_true",
         help="Allow re-installing existing firmware versions",
     )
     parser.add_argument(
-        "--allow-older", action='store_true', help="Allow downgrading firmware versions"
+        "--allow-older", action="store_true", help="Allow downgrading firmware versions"
     )
     parser.add_argument(
         "command", choices=["install", "extract"], help="Command to run"
@@ -61,7 +61,7 @@ def bytes_slicer(length, source):
 def get_zip():
     script = os.path.realpath(__file__)
     bytes_out = io.BytesIO()
-    with open(script, 'rb') as source:
+    with open(script, "rb") as source:
         for line in source:
             if not line.startswith(TAG):
                 continue
@@ -71,7 +71,7 @@ def get_zip():
 
 def unzip(destination):
     zipf = get_zip()
-    source = zipfile.ZipFile(zipf, 'r')
+    source = zipfile.ZipFile(zipf, "r")
     for item in source.namelist():
         # extract handles the sanitization
         source.extract(item, destination)
@@ -83,7 +83,7 @@ def copy_cabs(source, target):
     cabs = []
     for root, dirs, files in os.walk(source):
         for f in files:
-            if f.endswith('.cab'):
+            if f.endswith(".cab"):
                 origf = os.path.join(root, f)
                 shutil.copy(origf, target)
                 cabs.append(os.path.join(target, f))
@@ -91,31 +91,31 @@ def copy_cabs(source, target):
 
 
 def install_snap(directory, verbose, allow_reinstall, allow_older, uninstall):
-    app = 'fwupd'
-    common = '/root/snap/%s/common' % app
+    app = "fwupd"
+    common = "/root/snap/%s/common" % app
 
     # check if snap is installed
-    with open(os.devnull, 'w') as devnull:
-        subprocess.run(['snap'], check=True, stdout=devnull, stderr=devnull)
+    with open(os.devnull, "w") as devnull:
+        subprocess.run(["snap"], check=True, stdout=devnull, stderr=devnull)
 
     # check existing installed
-    cmd = ['snap', 'list', app]
-    with open(os.devnull, 'w') as devnull:
+    cmd = ["snap", "list", app]
+    with open(os.devnull, "w") as devnull:
         if verbose:
             print(cmd)
         ret = subprocess.run(cmd, stdout=devnull, stderr=devnull)
         if ret.returncode == 0:
-            cmd = ['snap', 'remove', app]
+            cmd = ["snap", "remove", app]
             if verbose:
                 print(cmd)
             subprocess.run(cmd, check=True)
 
     # install the snap
-    cmd = ['snap', 'ack', os.path.join(directory, 'fwupd.assert')]
+    cmd = ["snap", "ack", os.path.join(directory, "fwupd.assert")]
     if verbose:
         print(cmd)
     subprocess.run(cmd, check=True)
-    cmd = ['snap', 'install', '--classic', os.path.join(directory, 'fwupd.snap')]
+    cmd = ["snap", "install", "--classic", os.path.join(directory, "fwupd.snap")]
     if verbose:
         print(cmd)
     subprocess.run(cmd, check=True)
@@ -125,7 +125,7 @@ def install_snap(directory, verbose, allow_reinstall, allow_older, uninstall):
 
     # run the snap
     for cab in cabs:
-        cmd = ["%s.fwupdmgr" % app, 'install', cab]
+        cmd = ["%s.fwupdmgr" % app, "install", cab]
         if allow_reinstall:
             cmd += ["--allow-reinstall"]
         if allow_older:
@@ -141,61 +141,61 @@ def install_snap(directory, verbose, allow_reinstall, allow_older, uninstall):
 
     # cleanup
     if uninstall:
-        cmd = ['snap', 'remove', app]
+        cmd = ["snap", "remove", app]
         if verbose:
             print(cmd)
         subprocess.run(cmd)
 
 
 def install_flatpak(directory, verbose, allow_reinstall, allow_older, uninstall):
-    app = 'org.freedesktop.fwupd'
-    common = '%s/.var/app/%s' % (os.getenv('HOME'), app)
+    app = "org.freedesktop.fwupd"
+    common = "%s/.var/app/%s" % (os.getenv("HOME"), app)
 
-    with open(os.devnull, 'w') as devnull:
+    with open(os.devnull, "w") as devnull:
         if not verbose:
             output = devnull
         else:
             output = None
         # look for dependencies
-        dep = 'org.gnome.Platform/x86_64/3.30'
-        repo = 'flathub'
-        repo_url = 'https://flathub.org/repo/flathub.flatpakrepo'
-        cmd = ['flatpak', 'info', dep]
+        dep = "org.gnome.Platform/x86_64/3.30"
+        repo = "flathub"
+        repo_url = "https://flathub.org/repo/flathub.flatpakrepo"
+        cmd = ["flatpak", "info", dep]
         if verbose:
             print(cmd)
         ret = subprocess.run(cmd, stdout=output, stderr=output)
         # not installed
         if ret.returncode != 0:
             # look for remotes
-            cmd = ['flatpak', 'remote-info', repo, dep]
+            cmd = ["flatpak", "remote-info", repo, dep]
             if verbose:
                 print(cmd)
             ret = subprocess.run(cmd, stdout=output, stderr=output)
             # not enabled, enable it
             if ret.returncode != 0:
-                cmd = ['flatpak', 'remote-add', repo, repo_url]
+                cmd = ["flatpak", "remote-add", repo, repo_url]
                 if verbose:
                     print(cmd)
                 ret = subprocess.run(cmd, stderr=output)
             # install dep
-            cmd = ['flatpak', 'install', repo, dep]
+            cmd = ["flatpak", "install", repo, dep]
             if verbose:
                 print(cmd)
             ret = subprocess.run(cmd)
 
         # check existing installed
-        cmd = ['flatpak', 'info', app]
+        cmd = ["flatpak", "info", app]
         if verbose:
             print(cmd)
         ret = subprocess.run(cmd, stdout=output, stderr=output)
         if ret.returncode == 0:
-            cmd = ['flatpak', 'remove', app]
+            cmd = ["flatpak", "remove", app]
             if verbose:
                 print(cmd)
             subprocess.run(cmd, check=True)
 
     # install the flatpak
-    cmd = ['flatpak', 'install', os.path.join(directory, 'fwupd.flatpak')]
+    cmd = ["flatpak", "install", os.path.join(directory, "fwupd.flatpak")]
     if verbose:
         print(cmd)
     subprocess.run(cmd, check=True)
@@ -205,7 +205,7 @@ def install_flatpak(directory, verbose, allow_reinstall, allow_older, uninstall)
 
     # run command
     for cab in cabs:
-        cmd = ['flatpak', 'run', app, 'install', cab]
+        cmd = ["flatpak", "run", app, "install", cab]
         if allow_reinstall:
             cmd += ["--allow-reinstall"]
         if allow_older:
@@ -221,7 +221,7 @@ def install_flatpak(directory, verbose, allow_reinstall, allow_older, uninstall)
 
     # cleanup
     if uninstall:
-        cmd = ['flatpak', 'remove', app]
+        cmd = ["flatpak", "remove", app]
         if verbose:
             print(cmd)
         subprocess.run(cmd)
@@ -261,10 +261,10 @@ def remove_packaged_version(pkg, cache):
     res = False
     while True:
         res = input("Remove now (Y/N)? ")
-        if res.lower() == 'n':
+        if res.lower() == "n":
             res = False
             break
-        if res.lower() == 'y':
+        if res.lower() == "y":
             res = True
             break
     if res:
@@ -279,11 +279,11 @@ def install_builtin(directory, verbose, allow_reinstall, allow_older):
     cabs = []
     for root, dirs, files in os.walk(directory):
         for f in files:
-            if f.endswith('.cab'):
+            if f.endswith(".cab"):
                 cabs.append(os.path.join(root, f))
     # run command
     for cab in cabs:
-        cmd = ['fwupdmgr', 'install', cab]
+        cmd = ["fwupdmgr", "install", cab]
         if allow_reinstall:
             cmd += ["--allow-reinstall"]
         if allow_older:
@@ -310,18 +310,18 @@ def run_installation(directory, verbose, allow_reinstall, allow_older, uninstall
         return
 
     # determine what self extracting binary has
-    if os.path.exists(os.path.join(directory, 'fwupd.snap')) and os.path.exists(
-        os.path.join(directory, 'fwupd.assert')
+    if os.path.exists(os.path.join(directory, "fwupd.snap")) and os.path.exists(
+        os.path.join(directory, "fwupd.assert")
     ):
         try_snap = True
-    if os.path.exists(os.path.join(directory, 'fwupd.flatpak')):
+    if os.path.exists(os.path.join(directory, "fwupd.flatpak")):
         try_flatpak = True
 
     if try_snap:
         try:
             install_snap(directory, verbose, allow_reinstall, allow_older, uninstall)
             return True
-        except Exception as _:
+        except Exception:
             if verbose:
                 print("Snap installation failed")
             if not try_flatpak:
@@ -330,9 +330,9 @@ def run_installation(directory, verbose, allow_reinstall, allow_older, uninstall
         install_flatpak(directory, verbose, allow_reinstall, allow_older, uninstall)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     args = parse_args()
-    if 'extract' in args.command:
+    if "extract" in args.command:
         if args.allow_reinstall:
             error(
                 "allow-reinstall argument doesn't make sense with command %s"
@@ -358,7 +358,7 @@ if __name__ == '__main__':
             )
         if os.getuid() != 0:
             error("This tool must be run as root")
-        with tempfile.TemporaryDirectory(prefix='fwupd') as target:
+        with tempfile.TemporaryDirectory(prefix="fwupd") as target:
             unzip(target)
             run_installation(
                 target,
