@@ -1,13 +1,16 @@
 #!/bin/sh
+set -e
+
+exec 2>&1
 
 # only run as root, possibly only in CI
 if [ "$(id -u)" -ne 0 ]; then exit 0; fi
 
 # ---
 echo "Starting P2P daemon..."
-export FWUPD_DBUS_SOCKET="/var/run/fwupd.sock"
+export FWUPD_DBUS_SOCKET="/run/fwupd.sock"
 rm -rf ${FWUPD_DBUS_SOCKET}
-/usr/libexec/fwupd/fwupd --verbose --timed-exit --no-timestamp &
+@libexecdir@/fwupd/fwupd --verbose --timed-exit --no-timestamp &
 while [ ! -e ${FWUPD_DBUS_SOCKET} ]; do sleep 1; done
 
 # ---
