@@ -39,6 +39,7 @@ typedef struct {
 	GPtrArray *protocols;
 	GPtrArray *instance_ids;
 	GPtrArray *icons;
+	GPtrArray *issues; /* of utf-8 */
 	gchar *name;
 	gchar *serial;
 	gchar *summary;
@@ -128,6 +129,47 @@ fwupd_device_add_checksum(FwupdDevice *self, const gchar *checksum)
 	g_ptr_array_add(priv->checksums, g_strdup(checksum));
 }
 
+/**
+ * fwupd_device_get_issues:
+ * @self: a #FwupdDevice
+ *
+ * Gets the list of issues currently affecting this device.
+ *
+ * Returns: (element-type utf8) (transfer none): the issues, which may be empty
+ *
+ * Since: 1.7.6
+ **/
+GPtrArray *
+fwupd_device_get_issues(FwupdDevice *self)
+{
+	FwupdDevicePrivate *priv = GET_PRIVATE(self);
+	g_return_val_if_fail(FWUPD_IS_DEVICE(self), NULL);
+	return priv->issues;
+}
+
+/**
+ * fwupd_device_add_issue:
+ * @self: a #FwupdDevice
+ * @issue: (not nullable): the update issue, e.g. `CVE-2019-12345`
+ *
+ * Adds an current issue to this device.
+ *
+ * Since: 1.7.6
+ **/
+void
+fwupd_device_add_issue(FwupdDevice *self, const gchar *issue)
+{
+	FwupdDevicePrivate *priv = GET_PRIVATE(self);
+	g_return_if_fail(FWUPD_IS_DEVICE(self));
+	g_return_if_fail(issue != NULL);
+	for (guint i = 0; i < priv->issues->len; i++) {
+		const gchar *issue_tmp = g_ptr_array_index(priv->issues, i);
+		if (g_strcmp0(issue_tmp, issue) == 0)
+			return;
+	}
+	g_ptr_array_add(priv->issues, g_strdup(issue));
+}
+
 /**
  * fwupd_device_get_children:
  * @self: a #FwupdDevice
@@ -453,6 +495,7 @@ fwupd_device_set_parent(FwupdDevice *self, FwupdDevice *parent)
 {
 	FwupdDevicePrivate *priv = GET_PRIVATE(self);
 	g_return_if_fail(FWUPD_IS_DEVICE(self));
+	g_return_if_fail(self != parent);
 
 	if (priv->parent != NULL)
 		g_object_remove_weak_pointer(G_OBJECT(priv->parent), (gpointer *)&priv->parent);
@@ -491,6 +534,9 @@ void
 fwupd_device_add_child(FwupdDevice *self, FwupdDevice *child)
 {
 	FwupdDevicePrivate *priv = GET_PRIVATE(self);
+	g_return_if_fail(FWUPD_IS_DEVICE(self));
+	g_return_if_fail(FWUPD_IS_DEVICE(child));
+	g_return_if_fail(self != child);
 
 	/* add if the child does not already exist */
 	for (guint i = 0; i < priv->children->len; i++) {
@@ -1841,6 +1887,15 @@ fwupd_device_to_variant_full(FwupdDevice *self, FwupdDeviceFlags flags)
 				      FWUPD_RESULT_KEY_PROTOCOL,
 				      g_variant_new_string(str->str));
 	}
+	if (priv->issues->len > 0) {
+		g_autofree const gchar **strv = g_new0(const gchar *, priv->issues->len + 1);
+		for (guint i = 0; i < priv->issues->len; i++)
+			strv[i] = (const gchar *)g_ptr_array_index(priv->issues, i);
+		g_variant_builder_add(&builder,
+				      "{sv}",
+				      FWUPD_RESULT_KEY_ISSUES,
+				      g_variant_new_strv(strv, -1));
+	}
 	if (priv->version != NULL) {
 		g_variant_builder_add(&builder,
 				      "{sv}",
@@ -1869,7 +1924,7 @@ fwupd_device_to_variant_full(FwupdDevice *self, FwupdDeviceFlags flags)
 		g_variant_builder_add(&builder,
 				      "{sv}",
 				      FWUPD_RESULT_KEY_VERSION_LOWEST_RAW,
-				      g_variant_new_uint64(priv->version_raw));
+				      g_variant_new_uint64(priv->version_lowest_raw));
 	}
 	if (priv->version_bootloader_raw > 0) {
 		g_variant_builder_add(&builder,
@@ -2086,6 +2141,12 @@ fwupd_device_from_key_value(FwupdDevice *self, const gchar *key, GVariant *value
 			fwupd_device_add_protocol(self, protocols[i]);
 		return;
 	}
+	if (g_strcmp0(key, FWUPD_RESULT_KEY_ISSUES) == 0) {
+		g_autofree const gchar **strv = g_variant_get_strv(value, NULL);
+		for (guint i = 0; strv[i] != NULL; i++)
+			fwupd_device_add_issue(self, strv[i]);
+		return;
+	}
 	if (g_strcmp0(key, FWUPD_RESULT_KEY_VERSION) == 0) {
 		fwupd_device_set_version(self, g_variant_get_string(value, NULL));
 		return;
@@ -2242,9 +2303,9 @@ fwupd_device_set_update_state(FwupdDevice *self, FwupdUpdateState update_state)
  * fwupd_device_get_version_format:
  * @self: a #FwupdDevice
  *
- * Gets the update state.
+ * Gets the version format.
  *
- * Returns: the update state, or %FWUPD_VERSION_FORMAT_UNKNOWN if unset
+ * Returns: the version format, or %FWUPD_VERSION_FORMAT_UNKNOWN if unset
  *
  * Since: 1.2.9
  **/
@@ -2259,9 +2320,9 @@ fwupd_device_get_version_format(FwupdDevice *self)
 /**
  * fwupd_device_set_version_format:
  * @self: a #FwupdDevice
- * @version_format: the state, e.g. %FWUPD_VERSION_FORMAT_PENDING
+ * @version_format: the version format, e.g. %FWUPD_VERSION_FORMAT_NUMBER
  *
- * Sets the update state.
+ * Sets the version format.
  *
  * Since: 1.2.9
  **/
@@ -2608,7 +2669,7 @@ fwupd_device_to_json(FwupdDevice *self, JsonBuilder *builder)
 	fwupd_common_json_add_string(builder, FWUPD_RESULT_KEY_PLUGIN, priv->plugin);
 	fwupd_common_json_add_string(builder, FWUPD_RESULT_KEY_PROTOCOL, priv->protocol);
 	if (priv->protocols->len > 1) { /* --> 0 when bumping API */
-		json_builder_set_member_name(builder, "VendorIds");
+		json_builder_set_member_name(builder, "Protocols");
 		json_builder_begin_array(builder);
 		for (guint i = 0; i < priv->protocols->len; i++) {
 			const gchar *tmp = g_ptr_array_index(priv->protocols, i);
@@ -2616,6 +2677,15 @@ fwupd_device_to_json(FwupdDevice *self, JsonBuilder *builder)
 		}
 		json_builder_end_array(builder);
 	}
+	if (priv->issues->len > 0) {
+		json_builder_set_member_name(builder, FWUPD_RESULT_KEY_ISSUES);
+		json_builder_begin_array(builder);
+		for (guint i = 0; i < priv->issues->len; i++) {
+			const gchar *tmp = g_ptr_array_index(priv->issues, i);
+			json_builder_add_string_value(builder, tmp);
+		}
+		json_builder_end_array(builder);
+	}
 	if (priv->flags != FWUPD_DEVICE_FLAG_NONE) {
 		json_builder_set_member_name(builder, FWUPD_RESULT_KEY_FLAGS);
 		json_builder_begin_array(builder);
@@ -2767,7 +2837,7 @@ gchar *
 fwupd_device_to_string(FwupdDevice *self)
 {
 	FwupdDevicePrivate *priv = GET_PRIVATE(self);
-	GString *str = g_string_new(NULL);
+	g_autoptr(GString) str = g_string_new(NULL);
 	g_autoptr(GPtrArray) guid_helpers = NULL;
 
 	g_return_val_if_fail(FWUPD_IS_DEVICE(self), NULL);
@@ -2821,6 +2891,10 @@ fwupd_device_to_string(FwupdDevice *self)
 		const gchar *tmp = g_ptr_array_index(priv->protocols, i);
 		fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_PROTOCOL, tmp);
 	}
+	for (guint i = 0; i < priv->issues->len; i++) {
+		const gchar *tmp = g_ptr_array_index(priv->issues, i);
+		fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_ISSUES, tmp);
+	}
 	fwupd_pad_kv_dfl(str, FWUPD_RESULT_KEY_FLAGS, priv->flags);
 	for (guint i = 0; i < priv->checksums->len; i++) {
 		const gchar *checksum = g_ptr_array_index(priv->checksums, i);
@@ -2880,7 +2954,7 @@ fwupd_device_to_string(FwupdDevice *self)
 		g_string_append_printf(str, "  \n  [%s]\n%s", FWUPD_RESULT_KEY_RELEASE, tmp);
 	}
 
-	return g_string_free(str, FALSE);
+	return g_string_free(g_steal_pointer(&str), FALSE);
 }
 
 static void
@@ -3116,6 +3190,7 @@ fwupd_device_init(FwupdDevice *self)
 	priv->checksums = g_ptr_array_new_with_free_func(g_free);
 	priv->vendor_ids = g_ptr_array_new_with_free_func(g_free);
 	priv->protocols = g_ptr_array_new_with_free_func(g_free);
+	priv->issues = g_ptr_array_new_with_free_func(g_free);
 	priv->children = g_ptr_array_new_with_free_func((GDestroyNotify)g_object_unref);
 	priv->releases = g_ptr_array_new_with_free_func((GDestroyNotify)g_object_unref);
 }
@@ -3159,6 +3234,7 @@ fwupd_device_finalize(GObject *object)
 	g_ptr_array_unref(priv->checksums);
 	g_ptr_array_unref(priv->children);
 	g_ptr_array_unref(priv->releases);
+	g_ptr_array_unref(priv->issues);
 
 	G_OBJECT_CLASS(fwupd_device_parent_class)->finalize(object);
 }
