@@ -12,7 +12,7 @@
  * fwupd_status_to_string:
  * @status: a status, e.g. %FWUPD_STATUS_DECOMPRESSING
  *
- * Converts a enumerated status to a string.
+ * Converts an enumerated status to a string.
  *
  * Returns: identifier string
  *
@@ -145,6 +145,8 @@ fwupd_device_flag_to_string(FwupdDeviceFlags device_flag)
 		return "wait-for-replug";
 	if (device_flag == FWUPD_DEVICE_FLAG_IGNORE_VALIDATION)
 		return "ignore-validation";
+	if (device_flag == FWUPD_DEVICE_FLAG_TRUSTED)
+		return "trusted";
 	if (device_flag == FWUPD_DEVICE_FLAG_ANOTHER_WRITE_REQUIRED)
 		return "another-write-required";
 	if (device_flag == FWUPD_DEVICE_FLAG_NO_AUTO_INSTANCE_IDS)
@@ -203,6 +205,10 @@ fwupd_device_flag_to_string(FwupdDeviceFlags device_flag)
 		return "affects-fde";
 	if (device_flag == FWUPD_DEVICE_FLAG_END_OF_LIFE)
 		return "end-of-life";
+	if (device_flag == FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD)
+		return "signed-payload";
+	if (device_flag == FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD)
+		return "unsigned-payload";
 	if (device_flag == FWUPD_DEVICE_FLAG_UNKNOWN)
 		return "unknown";
 	return NULL;
@@ -212,7 +218,7 @@ fwupd_device_flag_to_string(FwupdDeviceFlags device_flag)
  * fwupd_device_flag_from_string:
  * @device_flag: (nullable): a string, e.g. `require-ac`
  *
- * Converts a string to a enumerated device flag.
+ * Converts a string to an enumerated device flag.
  *
  * Returns: enumerated value
  *
@@ -258,6 +264,8 @@ fwupd_device_flag_from_string(const gchar *device_flag)
 		return FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG;
 	if (g_strcmp0(device_flag, "ignore-validation") == 0)
 		return FWUPD_DEVICE_FLAG_IGNORE_VALIDATION;
+	if (g_strcmp0(device_flag, "trusted") == 0)
+		return FWUPD_DEVICE_FLAG_TRUSTED;
 	if (g_strcmp0(device_flag, "another-write-required") == 0)
 		return FWUPD_DEVICE_FLAG_ANOTHER_WRITE_REQUIRED;
 	if (g_strcmp0(device_flag, "no-auto-instance-ids") == 0)
@@ -316,6 +324,10 @@ fwupd_device_flag_from_string(const gchar *device_flag)
 		return FWUPD_DEVICE_FLAG_AFFECTS_FDE;
 	if (g_strcmp0(device_flag, "end-of-life") == 0)
 		return FWUPD_DEVICE_FLAG_END_OF_LIFE;
+	if (g_strcmp0(device_flag, "signed-payload") == 0)
+		return FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD;
+	if (g_strcmp0(device_flag, "unsigned-payload") == 0)
+		return FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD;
 	return FWUPD_DEVICE_FLAG_UNKNOWN;
 }
 
@@ -413,7 +425,7 @@ fwupd_plugin_flag_from_string(const gchar *plugin_flag)
  * fwupd_update_state_to_string:
  * @update_state: the update state, e.g. %FWUPD_UPDATE_STATE_PENDING
  *
- * Converts a enumerated update state to a string.
+ * Converts an enumerated update state to a string.
  *
  * Returns: identifier string
  *
@@ -441,7 +453,7 @@ fwupd_update_state_to_string(FwupdUpdateState update_state)
  * fwupd_update_state_from_string:
  * @update_state: (nullable): a string, e.g. `pending`
  *
- * Converts a string to a enumerated update state.
+ * Converts a string to an enumerated update state.
  *
  * Returns: enumerated value
  *
@@ -469,7 +481,7 @@ fwupd_update_state_from_string(const gchar *update_state)
  * fwupd_trust_flag_to_string:
  * @trust_flag: the trust flags, e.g. %FWUPD_TRUST_FLAG_PAYLOAD
  *
- * Converts a enumerated trust flag to a string.
+ * Converts an enumerated trust flag to a string.
  *
  * Returns: identifier string
  *
@@ -491,7 +503,7 @@ fwupd_trust_flag_to_string(FwupdTrustFlags trust_flag)
  * fwupd_trust_flag_from_string:
  * @trust_flag: (nullable): a string, e.g. `payload`
  *
- * Converts a string to a enumerated trust flag.
+ * Converts a string to an enumerated trust flag.
  *
  * Returns: enumerated value
  *
@@ -545,7 +557,7 @@ fwupd_feature_flag_to_string(FwupdFeatureFlags feature_flag)
  * fwupd_feature_flag_from_string:
  * @feature_flag: (nullable): a string, e.g. `detach-action`
  *
- * Converts a string to a enumerated feature flag.
+ * Converts a string to an enumerated feature flag.
  *
  * Returns: enumerated value
  *
@@ -625,7 +637,7 @@ fwupd_keyring_kind_to_string(FwupdKeyringKind keyring_kind)
  * fwupd_release_flag_to_string:
  * @release_flag: a release flag, e.g. %FWUPD_RELEASE_FLAG_TRUSTED_PAYLOAD
  *
- * Converts a enumerated release flag to a string.
+ * Converts an enumerated release flag to a string.
  *
  * Returns: identifier string
  *
