@@ -504,6 +504,25 @@ typedef enum {
  * Since: 1.7.5
  */
 #define FWUPD_DEVICE_FLAG_END_OF_LIFE (1llu << 46)
+/**
+ * FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD:
+ *
+ * The firmware payload is verified on-device the payload using strong cryptography such
+ * as RSA, AES or ECC.
+ *
+ * It is usually not possible to modify or flash custom firmware not provided by the vendor.
+ *
+ * Since: 1.7.6
+ */
+#define FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD (1llu << 47)
+/**
+ * FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD:
+ *
+ * The firmware payload is unsigned and it is possible to modify and flash custom firmware.
+ *
+ * Since: 1.7.6
+ */
+#define FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD (1llu << 48)
 /**
  * FWUPD_DEVICE_FLAG_UNKNOWN:
  *
@@ -845,7 +864,7 @@ typedef enum {
  * @FWUPD_KEYRING_KIND_PKCS7:			Verification using PKCS7
  * @FWUPD_KEYRING_KIND_JCAT:			Verification using Jcat
  *
- * The update state.
+ * Type of keyring used on a remote.
  **/
 typedef enum {
 	FWUPD_KEYRING_KIND_UNKNOWN, /* Since: 0.9.7 */
