@@ -12,9 +12,9 @@
 
 G_BEGIN_DECLS
 
-GVariant	*fwupd_plugin_to_variant		(FwupdPlugin	*plugin);
-void		 fwupd_plugin_to_json			(FwupdPlugin	*plugin,
-							 JsonBuilder	*builder);
+GVariant *
+fwupd_plugin_to_variant(FwupdPlugin *self);
+void
+fwupd_plugin_to_json(FwupdPlugin *self, JsonBuilder *builder);
 
 G_END_DECLS
-
