@@ -109,7 +109,7 @@ typedef enum {
  * chain of slow USB hubs. This should be used when the device is able to
  * reset itself between bootloader->runtime->bootloader.
  */
-#define FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE 10000
+#define FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE 10000 /* ms */
 
 /**
  * FU_DEVICE_REMOVE_DELAY_USER_REPLUG:
@@ -118,7 +118,7 @@ typedef enum {
  * being slow and clumsy. This should be used when the user has to do something,
  * e.g. unplug, press a magic button and then replug.
  */
-#define FU_DEVICE_REMOVE_DELAY_USER_REPLUG 40000
+#define FU_DEVICE_REMOVE_DELAY_USER_REPLUG 40000 /* ms */
 
 /**
  * FuDeviceRetryFunc:
@@ -148,6 +148,7 @@ fu_device_new_with_context(FuContext *ctx);
 #define fu_device_add_release(d, v)	   fwupd_device_add_release(FWUPD_DEVICE(d), v)
 #define fu_device_add_icon(d, v)	   fwupd_device_add_icon(FWUPD_DEVICE(d), v)
 #define fu_device_has_icon(d, v)	   fwupd_device_has_icon(FWUPD_DEVICE(d), v)
+#define fu_device_add_issue(d, v)	   fwupd_device_add_issue(FWUPD_DEVICE(d), v)
 #define fu_device_set_created(d, v)	   fwupd_device_set_created(FWUPD_DEVICE(d), v)
 #define fu_device_set_description(d, v)	   fwupd_device_set_description(FWUPD_DEVICE(d), v)
 #define fu_device_set_flags(d, v)	   fwupd_device_set_flags(FWUPD_DEVICE(d), v)
@@ -178,6 +179,7 @@ fu_device_new_with_context(FuContext *ctx);
 #define fu_device_get_guid_default(d)	     fwupd_device_get_guid_default(FWUPD_DEVICE(d))
 #define fu_device_get_instance_ids(d)	     fwupd_device_get_instance_ids(FWUPD_DEVICE(d))
 #define fu_device_get_icons(d)		     fwupd_device_get_icons(FWUPD_DEVICE(d))
+#define fu_device_get_issues(d)		     fwupd_device_get_issues(FWUPD_DEVICE(d))
 #define fu_device_get_name(d)		     fwupd_device_get_name(FWUPD_DEVICE(d))
 #define fu_device_get_serial(d)		     fwupd_device_get_serial(FWUPD_DEVICE(d))
 #define fu_device_get_summary(d)	     fwupd_device_get_summary(FWUPD_DEVICE(d))
@@ -427,6 +429,24 @@ typedef guint64 FuDeviceInternalFlags;
  */
 #define FU_DEVICE_INTERNAL_FLAG_NO_LID_CLOSED (1ull << 21)
 
+/**
+ * FU_DEVICE_INTERNAL_FLAG_NO_PROBE:
+ *
+ * Do not probe this device.
+ *
+ * Since: 1.7.6
+ */
+#define FU_DEVICE_INTERNAL_FLAG_NO_PROBE (1ull << 22)
+
+/**
+ * FU_DEVICE_INTERNAL_FLAG_MD_SET_SIGNED:
+ *
+ * Set the signed/unsigned payload from the metadata if available.
+ *
+ * Since: 1.7.6
+ */
+#define FU_DEVICE_INTERNAL_FLAG_MD_SET_SIGNED (1ull << 23)
+
 /* accessors */
 gchar *
 fu_device_to_string(FuDevice *self);
