@@ -12,6 +12,7 @@
 #include <string.h>
 
 #ifdef _WIN32
+#include <errhandlingapi.h>
 #include <sysinfoapi.h>
 #endif
 
@@ -870,7 +871,8 @@ fu_smbios_setup(FuSmbios *self, GError **error)
 				return FALSE;
 			}
 			g_debug("ignoring %s", error_local->message);
-		}
+		} else
+			return TRUE;
 	}
 
 	/* the values the kernel parsed; these are world-readable */
