@@ -300,15 +300,15 @@ fu_udev_device_probe_serio(FuUdevDevice *self, GError **error)
 	/* firmware ID */
 	tmp = g_udev_device_get_property(priv->udev_device, "SERIO_FIRMWARE_ID");
 	if (tmp != NULL) {
-		g_autofree gchar *devid = NULL;
 		g_autofree gchar *id_safe = NULL;
 		/* this prefix is not useful */
 		if (g_str_has_prefix(tmp, "PNP: "))
 			tmp += 5;
-		id_safe = g_utf8_strup(tmp, -1);
-		g_strdelimit(id_safe, " /\\\"", '-');
-		devid = g_strdup_printf("SERIO\\FWID_%s", id_safe);
-		fu_device_add_instance_id(FU_DEVICE(self), devid);
+		id_safe = fu_common_instance_id_strsafe(tmp);
+		if (id_safe != NULL) {
+			g_autofree gchar *devid = g_strdup_printf("SERIO\\FWID_%s", id_safe);
+			fu_device_add_instance_id(FU_DEVICE(self), devid);
+		}
 	}
 	return TRUE;
 }
@@ -388,7 +388,7 @@ fu_udev_device_probe(FuDevice *device, GError **error)
 	/* set the version if the revision has been set */
 	if (fu_device_get_version(device) == NULL &&
 	    fu_device_get_version_format(device) == FWUPD_VERSION_FORMAT_UNKNOWN) {
-		if (priv->revision != 0x00) {
+		if (priv->revision != 0x00 && priv->revision != 0xFF) {
 			g_autofree gchar *version = g_strdup_printf("%02x", priv->revision);
 			fu_device_set_version_format(device, FWUPD_VERSION_FORMAT_PLAIN);
 			fu_device_set_version(device, version);
@@ -780,6 +780,7 @@ fu_udev_device_incorporate(FuDevice *self, FuDevice *donor)
 	FuUdevDevice *uself = FU_UDEV_DEVICE(self);
 	FuUdevDevice *udonor = FU_UDEV_DEVICE(donor);
 	FuUdevDevicePrivate *priv = GET_PRIVATE(uself);
+	FuUdevDevicePrivate *priv_donor = GET_PRIVATE(udonor);
 
 	g_return_if_fail(FU_IS_UDEV_DEVICE(self));
 	g_return_if_fail(FU_IS_UDEV_DEVICE(donor));
@@ -789,7 +790,18 @@ fu_udev_device_incorporate(FuDevice *self, FuDevice *donor)
 		fu_udev_device_set_subsystem(uself, fu_udev_device_get_subsystem(udonor));
 		fu_udev_device_set_bind_id(uself, fu_udev_device_get_bind_id(udonor));
 		fu_udev_device_set_device_file(uself, fu_udev_device_get_device_file(udonor));
+		fu_udev_device_set_driver(uself, fu_udev_device_get_driver(udonor));
 	}
+	if (priv->vendor == 0x0 && priv_donor->vendor != 0x0)
+		priv->vendor = priv_donor->vendor;
+	if (priv->model == 0x0 && priv_donor->model != 0x0)
+		priv->model = priv_donor->model;
+	if (priv->subsystem_vendor == 0x0 && priv_donor->subsystem_vendor != 0x0)
+		priv->subsystem_vendor = priv_donor->subsystem_vendor;
+	if (priv->subsystem_model == 0x0 && priv_donor->subsystem_model != 0x0)
+		priv->subsystem_model = priv_donor->subsystem_model;
+	if (priv->revision == 0x0 && priv_donor->revision != 0x0)
+		priv->revision = priv_donor->revision;
 }
 
 /**
@@ -1114,7 +1126,7 @@ fu_udev_device_set_physical_id(FuUdevDevice *self, const gchar *subsystems, GErr
 	} else if (g_strcmp0(subsystem, "usb") == 0 || g_strcmp0(subsystem, "mmc") == 0 ||
 		   g_strcmp0(subsystem, "i2c") == 0 || g_strcmp0(subsystem, "platform") == 0 ||
 		   g_strcmp0(subsystem, "scsi") == 0 || g_strcmp0(subsystem, "mtd") == 0 ||
-		   g_strcmp0(subsystem, "block") == 0) {
+		   g_strcmp0(subsystem, "block") == 0 || g_strcmp0(subsystem, "gpio") == 0) {
 		tmp = g_udev_device_get_property(udev_device, "DEVPATH");
 		if (tmp == NULL) {
 			g_set_error_literal(error,
@@ -1915,10 +1927,14 @@ fu_udev_device_get_siblings_with_subsystem(FuUdevDevice *self, const gchar *cons
 	g_autoptr(GList) enumerated = g_udev_client_query_by_subsystem(udev_client, subsystem);
 	for (GList *element = enumerated; element != NULL; element = element->next) {
 		g_autoptr(GUdevDevice) enumerated_device = element->data;
-		g_autoptr(GUdevDevice) enumerated_parent =
-		    g_udev_device_get_parent(enumerated_device);
-		const gchar *enumerated_parent_path =
-		    g_udev_device_get_sysfs_path(enumerated_parent);
+		g_autoptr(GUdevDevice) enumerated_parent = NULL;
+		const gchar *enumerated_parent_path;
+
+		/* get parent, if it exists */
+		enumerated_parent = g_udev_device_get_parent(enumerated_device);
+		if (enumerated_parent == NULL)
+			break;
+		enumerated_parent_path = g_udev_device_get_sysfs_path(enumerated_parent);
 
 		/* if the sysfs path of self's parent is the same as that of the
 		 * located device's parent, they are siblings */
@@ -1934,6 +1950,33 @@ fu_udev_device_get_siblings_with_subsystem(FuUdevDevice *self, const gchar *cons
 	return g_steal_pointer(&out);
 }
 
+/**
+ * fu_udev_device_get_parent_with_subsystem
+ * @self: a #FuUdevDevice
+ * @subsystem: the name of a udev subsystem
+ *
+ * Get the device that is a parent of self and has the provided subsystem.
+ *
+ * Returns: (transfer full): device, or %NULL
+ *
+ * Since: 1.7.6
+ */
+FuUdevDevice *
+fu_udev_device_get_parent_with_subsystem(FuUdevDevice *self, const gchar *subsystem)
+{
+#ifdef HAVE_GUDEV
+	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
+	g_autoptr(GUdevDevice) device_tmp = NULL;
+
+	device_tmp = g_udev_device_get_parent_with_subsystem(priv->udev_device, subsystem, NULL);
+	if (device_tmp == NULL)
+		return NULL;
+	return fu_udev_device_new_with_context(fu_device_get_context(FU_DEVICE(self)), device_tmp);
+#else
+	return NULL;
+#endif
+}
+
 /**
  * fu_udev_device_get_children_with_subsystem
  * @self: a #FuUdevDevice
@@ -1958,10 +2001,14 @@ fu_udev_device_get_children_with_subsystem(FuUdevDevice *self, const gchar *cons
 	g_autoptr(GList) enumerated = g_udev_client_query_by_subsystem(udev_client, subsystem);
 	for (GList *element = enumerated; element != NULL; element = element->next) {
 		g_autoptr(GUdevDevice) enumerated_device = element->data;
-		g_autoptr(GUdevDevice) enumerated_parent =
-		    g_udev_device_get_parent(enumerated_device);
-		const gchar *enumerated_parent_path =
-		    g_udev_device_get_sysfs_path(enumerated_parent);
+		g_autoptr(GUdevDevice) enumerated_parent = NULL;
+		const gchar *enumerated_parent_path;
+
+		/* get parent, if it exists */
+		enumerated_parent = g_udev_device_get_parent(enumerated_device);
+		if (enumerated_parent == NULL)
+			break;
+		enumerated_parent_path = g_udev_device_get_sysfs_path(enumerated_parent);
 
 		/* enumerated device is a child of self if its parent is the
 		 * same as self */
