@@ -11,8 +11,8 @@
 const gchar *
 fu_ccgx_dmc_update_model_type_to_string(DmcUpdateModel val)
 {
-	if (val == DMC_UPDATE_MODEL_UNKNOWN)
-		return "Unknown";
+	if (val == DMC_UPDATE_MODEL_NONE)
+		return "None";
 	if (val == DMC_UPDATE_MODEL_DOWNLOAD_TRIGGER)
 		return "Download Trigger";
 	if (val == DMC_UPDATE_MODEL_PENDING_RESET)
