@@ -7,7 +7,7 @@
 
 #pragma once
 
-#include "fu-hid-device.h"
+#include <fwupdplugin.h>
 
-#define FU_TYPE_CCGX_HID_DEVICE (fu_ccgx_hid_device_get_type ())
-G_DECLARE_FINAL_TYPE (FuCcgxHidDevice, fu_ccgx_hid_device, FU, CCGX_HID_DEVICE, FuHidDevice)
+#define FU_TYPE_CCGX_HID_DEVICE (fu_ccgx_hid_device_get_type())
+G_DECLARE_FINAL_TYPE(FuCcgxHidDevice, fu_ccgx_hid_device, FU, CCGX_HID_DEVICE, FuHidDevice)
