@@ -371,8 +371,10 @@ fu_colorhug_device_setup(FuDevice *device, GError **error)
 		/* although guessing is a route to insanity, if the device has
 		 * provided the extra data it's because the BCD type was not
 		 * suitable -- and INTEL_ME is not relevant here */
-		fu_device_set_version_format(device, fu_common_version_guess_format(tmp));
-		fu_device_set_version(device, tmp);
+		if (tmp != NULL) {
+			fu_device_set_version_format(device, fu_common_version_guess_format(tmp));
+			fu_device_set_version(device, tmp);
+		}
 	}
 
 	/* get GUID from the descriptor if set */
@@ -560,6 +562,7 @@ fu_colorhug_device_init(FuColorhugDevice *self)
 	fu_device_add_protocol(FU_DEVICE(self), "com.hughski.colorhug");
 	fu_device_set_remove_delay(FU_DEVICE(self), FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_ADD_COUNTERPART_GUIDS);
+	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
 	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID);
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_COLORHUG_DEVICE_FLAG_HALFSIZE,
