@@ -826,7 +826,6 @@ fu_dell_dock_ec_write_fw(FuDevice *device,
 
 	/* meet the minimum EC version */
 	if ((flags & FWUPD_INSTALL_FLAG_FORCE) == 0 &&
-	    (self->data->module_type != MODULE_TYPE_130_USB4) &&
 	    (fu_common_vercmp_full(dynamic_version,
 				   self->ec_minimum_version,
 				   FWUPD_VERSION_FORMAT_QUAD) < 0)) {
@@ -1014,6 +1013,7 @@ fu_dell_dock_ec_init(FuDellDockEc *self)
 	self->raw_versions = g_new0(FuDellDockDockPackageFWVersion, 1);
 	fu_device_add_protocol(FU_DEVICE(self), "com.dell.dock");
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
+	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD);
 	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_INHIBIT_CHILDREN);
 }
 
