@@ -735,28 +735,28 @@ main(int argc, char *argv[])
 	     0,
 	     G_OPTION_ARG_NONE,
 	     &verbose,
-	     _("Print verbose debug statements"),
+	     N_("Print verbose debug statements"),
 	     NULL},
 	    {"device",
 	     'd',
 	     0,
 	     G_OPTION_ARG_STRING,
 	     &self->device_vid_pid,
-	     _("Specify Vendor/Product ID(s) of DFU device"),
-	     _("VID:PID")},
+	     N_("Specify Vendor/Product ID(s) of DFU device"),
+	     N_("VID:PID")},
 	    {"transfer-size",
 	     't',
 	     0,
 	     G_OPTION_ARG_STRING,
 	     &self->transfer_size,
-	     _("Specify the number of bytes per USB transfer"),
-	     _("BYTES")},
+	     N_("Specify the number of bytes per USB transfer"),
+	     N_("BYTES")},
 	    {"force",
 	     '\0',
 	     0,
 	     G_OPTION_ARG_NONE,
 	     &self->force,
-	     _("Force the action ignoring all warnings"),
+	     N_("Force the action ignoring all warnings"),
 	     NULL},
 	    {NULL}};
 
