@@ -1,5 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
+/*
  * Copyright (C) 2017 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2019 9elements Agency GmbH <patrick.rudolph@9elements.com>
  *
@@ -97,7 +96,6 @@ fu_plugin_flashrom_device_set_bios_info(FuPlugin *plugin, FuDevice *device)
 	const guint8 *buf;
 	gsize bufsz;
 	guint32 bios_char = 0x0;
-	guint8 bios_sz = 0x0;
 	g_autoptr(GBytes) bios_table = NULL;
 
 	/* get SMBIOS info */
@@ -105,11 +103,14 @@ fu_plugin_flashrom_device_set_bios_info(FuPlugin *plugin, FuDevice *device)
 	if (bios_table == NULL)
 		return;
 
-	/* ROM size */
+	/* ROM size if not already been quirked */
 	buf = g_bytes_get_data(bios_table, &bufsz);
-	if (fu_common_read_uint8_safe(buf, bufsz, 0x9, &bios_sz, NULL)) {
-		guint64 firmware_size = (bios_sz + 1) * 64 * 1024;
-		fu_device_set_firmware_size_max(device, firmware_size);
+	if (fu_device_get_firmware_size_max(device) == 0) {
+		guint8 bios_sz = 0x0;
+		if (fu_common_read_uint8_safe(buf, bufsz, 0x9, &bios_sz, NULL)) {
+			guint64 firmware_size = (bios_sz + 1) * 64 * 1024;
+			fu_device_set_firmware_size_max(device, firmware_size);
+		}
 	}
 
 	/* BIOS characteristics */
