@@ -86,7 +86,7 @@ fu_plugin_mm_udev_device_ports_timeout(gpointer user_data)
 	dev = fu_plugin_cache_lookup(plugin, priv->inhibited->physical_id);
 	if (dev != NULL) {
 		if (!fu_device_probe(FU_DEVICE(dev), &error)) {
-			g_warning("failed to probe MM device: %s", error->message);
+			g_debug("failed to probe MM device: %s", error->message);
 		} else {
 			fu_plugin_device_add(plugin, FU_DEVICE(dev));
 		}
@@ -126,10 +126,6 @@ fu_plugin_mm_udev_device_port_added(FuPlugin *plugin,
 		fu_plugin_mm_udev_device_ports_timeout_reset(plugin);
 		return;
 	}
-
-	/* device is being created, update is complete, uninhibit */
-	fu_plugin_mm_uninhibit_device(plugin);
-
 	/* create device and add to cache */
 	dev = fu_mm_device_udev_new(fu_plugin_get_context(plugin), priv->manager, priv->inhibited);
 	fu_mm_device_udev_add_port(dev, subsystem, path, ifnum);
@@ -230,11 +226,12 @@ fu_plugin_mm_device_add(FuPlugin *plugin, MMObject *modem)
 	}
 	dev = fu_mm_device_new(fu_plugin_get_context(plugin), priv->manager, modem);
 	if (!fu_device_setup(FU_DEVICE(dev), &error)) {
-		g_warning("failed to probe MM device: %s", error->message);
+		g_debug("failed to probe MM device: %s", error->message);
 		return;
 	}
 	fu_plugin_device_add(plugin, FU_DEVICE(dev));
 	fu_plugin_cache_add(plugin, object_path, dev);
+	fu_plugin_cache_add(plugin, fu_device_get_physical_id(FU_DEVICE(dev)), dev);
 }
 
 static void
@@ -448,6 +445,33 @@ fu_plugin_mm_attach(FuPlugin *plugin, FuDevice *device, FuProgress *progress, GE
 	return TRUE;
 }
 
+static gboolean
+fu_plugin_mm_backend_device_added(FuPlugin *plugin, FuDevice *device, GError **error)
+{
+	FuDevice *device_tmp;
+	g_autoptr(GUdevDevice) udev_device = NULL;
+
+	/* interesting device? */
+	if (!FU_IS_USB_DEVICE(device))
+		return TRUE;
+
+	/* look up the FuMmDevice for the USB device that just appeared */
+	udev_device = fu_usb_device_find_udev_device(FU_USB_DEVICE(device), error);
+	if (udev_device == NULL)
+		return FALSE;
+	device_tmp = fu_plugin_cache_lookup(plugin, g_udev_device_get_sysfs_path(udev_device));
+	if (device_tmp == NULL) {
+		g_set_error(error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_NOT_SUPPORTED,
+			    "%s not added by ModemManager",
+			    g_udev_device_get_sysfs_path(udev_device));
+		return FALSE;
+	}
+	fu_mm_device_set_usb_device(FU_MM_DEVICE(device_tmp), FU_USB_DEVICE(device));
+	return TRUE;
+}
+
 void
 fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 {
@@ -458,4 +482,5 @@ fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 	vfuncs->coldplug = fu_plugin_mm_coldplug;
 	vfuncs->attach = fu_plugin_mm_attach;
 	vfuncs->detach = fu_plugin_mm_detach;
+	vfuncs->backend_device_added = fu_plugin_mm_backend_device_added;
 }
