@@ -27,13 +27,77 @@ fu_mtd_device_to_string(FuDevice *device, guint idt, GString *str)
 		fu_common_string_append_kx(str, idt, "EraseSize", self->erasesize);
 }
 
+static gboolean
+fu_mtd_device_setup(FuDevice *device, GError **error)
+{
+	GType firmware_gtype = fu_device_get_firmware_gtype(device);
+	const gchar *fn;
+	g_autoptr(FuFirmware) firmware = NULL;
+	g_autoptr(GFile) file = NULL;
+
+	/* nothing to do */
+	if (firmware_gtype == G_TYPE_INVALID)
+		return TRUE;
+
+	/* read entire contents */
+	fn = fu_udev_device_get_device_file(FU_UDEV_DEVICE(device));
+	if (fn == NULL) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "Not supported as no device file");
+		return FALSE;
+	}
+	file = g_file_new_for_path(fn);
+	firmware = g_object_new(firmware_gtype, NULL);
+	if (!fu_firmware_parse_file(firmware, file, FWUPD_INSTALL_FLAG_NONE, error))
+		return FALSE;
+
+	/* copy over the version */
+	if (fu_firmware_get_version(firmware) != NULL)
+		fu_device_set_version(device, fu_firmware_get_version(firmware));
+	if (fu_firmware_get_version_raw(firmware) != G_MAXUINT64)
+		fu_device_set_version_raw(device, fu_firmware_get_version_raw(firmware));
+
+	/* success */
+	return TRUE;
+}
+
+static gboolean
+fu_mtd_device_open(FuDevice *device, GError **error)
+{
+	g_autoptr(GError) error_local = NULL;
+
+	/* FuUdevDevice->open */
+	if (!FU_DEVICE_CLASS(fu_mtd_device_parent_class)->open(device, &error_local)) {
+		if (g_error_matches(error_local, G_IO_ERROR, G_IO_ERROR_PERMISSION_DENIED)) {
+			g_set_error_literal(error,
+					    FWUPD_ERROR,
+					    FWUPD_ERROR_NOT_SUPPORTED,
+					    error_local->message);
+			return FALSE;
+		}
+		g_propagate_error(error, g_steal_pointer(&error_local));
+		return FALSE;
+	}
+
+	/* success */
+	return TRUE;
+}
+
 static gboolean
 fu_mtd_device_probe(FuDevice *device, GError **error)
 {
+	FuContext *ctx = fu_device_get_context(device);
 	FuMtdDevice *self = FU_MTD_DEVICE(device);
 	const gchar *name;
+	const gchar *product;
+	const gchar *vendor;
 	guint64 flags = 0;
 	guint64 size = 0;
+	g_autofree gchar *name_safe = NULL;
+	g_autofree gchar *product_safe = NULL;
+	g_autofree gchar *vendor_safe = NULL;
 
 	/* FuUdevDevice->probe */
 	if (!FU_DEVICE_CLASS(fu_mtd_device_parent_class)->probe(device, error))
@@ -46,14 +110,44 @@ fu_mtd_device_probe(FuDevice *device, GError **error)
 	/* get name */
 	name = fu_udev_device_get_sysfs_attr(FU_UDEV_DEVICE(device), "name", NULL);
 	if (name != NULL) {
-		g_autofree gchar *devid = NULL;
-		g_autofree gchar *name_safe = g_strdup(name);
-		g_strdelimit(name_safe, " /\\\"", '-');
-		devid = g_strdup_printf("MTD\\NAME_%s", name_safe);
-		fu_device_add_instance_id(FU_DEVICE(self), devid);
+		name_safe = fu_common_instance_id_strsafe(name);
+		if (name_safe != NULL) {
+			g_autofree gchar *devid = g_strdup_printf("MTD\\NAME_%s", name_safe);
+			fu_device_add_instance_id(FU_DEVICE(self), devid);
+		}
 		fu_device_set_name(FU_DEVICE(self), name);
 	}
 
+	/* set vendor ID as the BIOS vendor */
+	vendor = fu_context_get_hwid_value(ctx, FU_HWIDS_KEY_MANUFACTURER);
+	if (vendor != NULL) {
+		g_autofree gchar *vendor_id = g_strdup_printf("DMI:%s", vendor);
+		fu_device_add_vendor_id(device, vendor_id);
+		vendor_safe = fu_common_instance_id_strsafe(vendor);
+	}
+
+	/* use vendor and product as an optional instance ID prefix */
+	product = fu_context_get_hwid_value(ctx, FU_HWIDS_KEY_PRODUCT_NAME);
+	if (product != NULL)
+		product_safe = fu_common_instance_id_strsafe(product);
+	if (vendor_safe != NULL && product_safe != NULL && name_safe != NULL) {
+		g_autofree gchar *devid = NULL;
+		devid = g_strdup_printf("MTD\\VENDOR_%s&PRODUCT_%s&NAME_%s",
+					vendor_safe,
+					product_safe,
+					name_safe);
+		fu_device_add_instance_id(device, devid);
+	}
+	if (vendor_safe != NULL && name_safe != NULL) {
+		g_autofree gchar *devid = NULL;
+		devid = g_strdup_printf("MTD\\VENDOR_%s&NAME_%s", vendor_safe, name_safe);
+		fu_device_add_instance_id(device, devid);
+	}
+	if (name_safe != NULL) {
+		g_autofree gchar *devid = g_strdup_printf("MTD\\NAME_%s", name_safe);
+		fu_device_add_instance_id(FU_DEVICE(self), devid);
+	}
+
 	/* get properties about the device */
 	if (!fu_udev_device_get_sysfs_attr_uint64(FU_UDEV_DEVICE(device), "size", &size, error))
 		return FALSE;
@@ -128,7 +222,7 @@ fu_mtd_device_write(FuMtdDevice *self, GPtrArray *chunks, FuProgress *progress,
 	for (guint i = 0; i < chunks->len; i++) {
 		FuChunk *chk = g_ptr_array_index(chunks, i);
 		if (!fu_udev_device_pwrite_full(FU_UDEV_DEVICE(self),
-						0x0,
+						fu_chunk_get_address(chk),
 						fu_chunk_get_data(chk),
 						fu_chunk_get_data_sz(chk),
 						error)) {
@@ -159,7 +253,7 @@ fu_mtd_device_verify(FuMtdDevice *self, GPtrArray *chunks, FuProgress *progress,
 		g_autoptr(GBytes) blob2 = NULL;
 
 		if (!fu_udev_device_pread_full(FU_UDEV_DEVICE(self),
-					       0x0,
+					       fu_chunk_get_address(chk),
 					       buf,
 					       fu_chunk_get_data_sz(chk),
 					       error)) {
@@ -207,6 +301,40 @@ fu_mtd_device_write_verify(FuMtdDevice *self, GBytes *fw, FuProgress *progress,
 	return TRUE;
 }
 
+static GBytes *
+fu_mtd_device_dump_firmware(FuDevice *device, FuProgress *progress, GError **error)
+{
+	FuMtdDevice *self = FU_MTD_DEVICE(device);
+	gsize bufsz = fu_device_get_firmware_size_max(device);
+	g_autofree guint8 *buf = g_malloc0(bufsz);
+	g_autoptr(GPtrArray) chunks = NULL;
+
+	/* progress */
+	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_set_status(progress, FWUPD_STATUS_DEVICE_READ);
+
+	/* read each chunk */
+	chunks = fu_chunk_array_mutable_new(buf, bufsz, 0x0, 0x0, 10 * 1024);
+	fu_progress_set_steps(progress, chunks->len);
+	for (guint i = 0; i < chunks->len; i++) {
+		FuChunk *chk = g_ptr_array_index(chunks, i);
+		if (!fu_udev_device_pread_full(FU_UDEV_DEVICE(self),
+					       fu_chunk_get_address(chk),
+					       fu_chunk_get_data_out(chk),
+					       fu_chunk_get_data_sz(chk),
+					       error)) {
+			g_prefix_error(error,
+				       "failed to read @0x%x: ",
+				       (guint)fu_chunk_get_address(chk));
+			return NULL;
+		}
+		fu_progress_step_done(progress);
+	}
+
+	/* success */
+	return g_bytes_new_take(g_steal_pointer(&buf), bufsz);
+}
+
 static gboolean
 fu_mtd_device_write_firmware(FuDevice *device,
 			     FuFirmware *firmware,
@@ -258,6 +386,12 @@ fu_mtd_device_write_firmware(FuDevice *device,
 static void
 fu_mtd_device_init(FuMtdDevice *self)
 {
+	fu_device_set_summary(FU_DEVICE(self), "Memory Technology Device");
+	fu_device_add_protocol(FU_DEVICE(self), "org.infradead.mtd");
+	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_INTERNAL);
+	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_NEEDS_REBOOT);
+	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_MD_SET_SIGNED);
+	fu_device_add_icon(FU_DEVICE(self), "drive-harddisk-solidstate");
 	fu_udev_device_set_flags(FU_UDEV_DEVICE(self),
 				 FU_UDEV_DEVICE_FLAG_OPEN_READ | FU_UDEV_DEVICE_FLAG_OPEN_WRITE |
 				     FU_UDEV_DEVICE_FLAG_OPEN_SYNC);
@@ -267,7 +401,10 @@ static void
 fu_mtd_device_class_init(FuMtdDeviceClass *klass)
 {
 	FuDeviceClass *klass_device = FU_DEVICE_CLASS(klass);
+	klass_device->open = fu_mtd_device_open;
 	klass_device->probe = fu_mtd_device_probe;
+	klass_device->setup = fu_mtd_device_setup;
 	klass_device->to_string = fu_mtd_device_to_string;
+	klass_device->dump_firmware = fu_mtd_device_dump_firmware;
 	klass_device->write_firmware = fu_mtd_device_write_firmware;
 }
