@@ -15,6 +15,8 @@ typedef struct {
 	JsonObject *member;
 	guint64 milestone;
 	gchar *build;
+	guint reset_pre_delay;	/* default of 0ms */
+	guint reset_post_delay; /* default of 0ms */
 } FuRedfishDevicePrivate;
 
 enum { PROP_0, PROP_BACKEND, PROP_MEMBER, PROP_LAST };
@@ -32,6 +34,8 @@ fu_redfish_device_to_string(FuDevice *device, guint idt, GString *str)
 		fu_common_string_append_kx(str, idt, "Milestone", priv->milestone);
 	if (priv->build != NULL)
 		fu_common_string_append_kv(str, idt, "Build", priv->build);
+	fu_common_string_append_ku(str, idt, "ResetPretDelay", priv->reset_pre_delay);
+	fu_common_string_append_ku(str, idt, "ResetPostDelay", priv->reset_post_delay);
 }
 
 static void
@@ -493,10 +497,8 @@ fu_redfish_device_probe(FuDevice *dev, GError **error)
 
 	/* reasons why the device might not be updatable */
 	if (json_object_has_member(member, "Updateable")) {
-		if (!json_object_get_boolean_member(member, "Updateable"))
-			fu_device_inhibit(dev, "not-updatable", "Updateable property is FALSE");
-		else
-			fu_device_uninhibit(dev, "not-updatable");
+		if (json_object_get_boolean_member(member, "Updateable"))
+			fu_device_add_flag(dev, FWUPD_DEVICE_FLAG_UPDATABLE);
 	}
 	if (fu_device_has_private_flag(dev, FU_REDFISH_DEVICE_FLAG_IS_BACKUP))
 		fu_device_inhibit(dev, "is-backup", "Is a backup partition");
@@ -759,6 +761,49 @@ fu_redfish_device_poll_task(FuRedfishDevice *self,
 	return FALSE;
 }
 
+guint
+fu_redfish_device_get_reset_pre_delay(FuRedfishDevice *self)
+{
+	FuRedfishDevicePrivate *priv = GET_PRIVATE(self);
+	return priv->reset_pre_delay;
+}
+
+guint
+fu_redfish_device_get_reset_post_delay(FuRedfishDevice *self)
+{
+	FuRedfishDevicePrivate *priv = GET_PRIVATE(self);
+	return priv->reset_post_delay;
+}
+
+static gboolean
+fu_redfish_device_set_quirk_kv(FuDevice *device,
+			       const gchar *key,
+			       const gchar *value,
+			       GError **error)
+{
+	FuRedfishDevice *self = FU_REDFISH_DEVICE(device);
+	FuRedfishDevicePrivate *priv = GET_PRIVATE(self);
+	guint64 tmp = 0;
+
+	if (g_strcmp0(key, "RedfishResetPreDelay") == 0) {
+		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT, error))
+			return FALSE;
+		priv->reset_pre_delay = tmp;
+		return TRUE;
+	}
+	if (g_strcmp0(key, "RedfishResetPostDelay") == 0) {
+		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT, error))
+			return FALSE;
+		priv->reset_post_delay = tmp;
+		return TRUE;
+	}
+	g_set_error_literal(error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_NOT_SUPPORTED,
+			    "quirk key not supported");
+	return FALSE;
+}
+
 static void
 fu_redfish_device_get_property(GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
@@ -804,11 +849,11 @@ fu_redfish_device_init(FuRedfishDevice *self)
 	fu_device_set_summary(FU_DEVICE(self), "Redfish device");
 	fu_device_add_protocol(FU_DEVICE(self), "org.dmtf.redfish");
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_REQUIRE_AC);
-	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_MD_SET_NAME);
 	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_MD_SET_VERFMT);
 	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_MD_SET_ICON);
 	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_MD_SET_VENDOR);
+	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_MD_SET_SIGNED);
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_REDFISH_DEVICE_FLAG_IS_BACKUP,
 					"is-backup");
@@ -818,6 +863,9 @@ fu_redfish_device_init(FuRedfishDevice *self)
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_REDFISH_DEVICE_FLAG_WILDCARD_TARGETS,
 					"wildcard-targets");
+	fu_device_register_private_flag(FU_DEVICE(self),
+					FU_REDFISH_DEVICE_FLAG_MANAGER_RESET,
+					"manager-reset");
 }
 
 static void
@@ -846,6 +894,7 @@ fu_redfish_device_class_init(FuRedfishDeviceClass *klass)
 
 	klass_device->to_string = fu_redfish_device_to_string;
 	klass_device->probe = fu_redfish_device_probe;
+	klass_device->set_quirk_kv = fu_redfish_device_set_quirk_kv;
 
 	/**
 	 * FuRedfishDevice:backend:
