@@ -250,7 +250,7 @@ fu_synaptics_cape_device_sendcmd_ex(FuSynapticsCapeDevice *self,
 		report.cmd.data_len = GINT16_TO_LE(report.cmd.data_len);
 	}
 
-	report.cmd.cmd_id = GUINT32_TO_LE(report.cmd.cmd_id);
+	report.cmd.cmd_id = GUINT16_TO_LE(report.cmd.cmd_id);
 	report.cmd.module_id = GUINT32_TO_LE(report.cmd.module_id);
 
 	if (!fu_synaptics_cape_device_set_report(self, &report, error)) {
@@ -352,8 +352,8 @@ fu_synaptics_cape_device_sendcmd(FuSynapticsCapeDevice *self,
 
 	g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
 
-	cmd.cmd_id = cmd_id;
-	cmd.module_id = module_id;
+	cmd.cmd_id = GUINT16_TO_LE(cmd_id);
+	cmd.module_id = GUINT32_TO_LE(module_id);
 
 	if (data_len != 0 && data != NULL) {
 		cmd.data_len = data_len;
@@ -460,9 +460,9 @@ fu_synaptics_cape_device_setup_version(FuSynapticsCapeDevice *self, GError **err
 	FuCapCmd cmd = {0};
 	g_autofree gchar *version_str = NULL;
 
-	cmd.cmd_id = GUINT32_TO_LE(FU_SYNAPTICS_CMD_GET_VERSION);
-	cmd.module_id = FU_SYNAPTICS_CAPE_CMD_APP_ID_CTRL;
-	cmd.data_len = 4;
+	cmd.cmd_id = GUINT16_TO_LE(FU_SYNAPTICS_CMD_GET_VERSION);
+	cmd.module_id = GUINT32_TO_LE(FU_SYNAPTICS_CAPE_CMD_APP_ID_CTRL);
+	cmd.data_len = GUINT16_TO_LE(4);
 
 	g_return_val_if_fail(FU_IS_SYNAPTICS_CAPE_DEVICE(self), FALSE);
 	g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
@@ -768,6 +768,7 @@ fu_synaptics_cape_device_init(FuSynapticsCapeDevice *self)
 {
 	fu_device_add_icon(FU_DEVICE(self), "audio-card");
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
+	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
 	fu_device_set_version_format(FU_DEVICE(self), FWUPD_VERSION_FORMAT_QUAD);
 	fu_device_set_install_duration(FU_DEVICE(self), 3); /* seconds */
 	fu_device_add_protocol(FU_DEVICE(self), "com.synaptics.cape");
