@@ -412,8 +412,8 @@ fu_synaptics_cxaudio_device_setup(FuDevice *device, GError **error)
 		return FALSE;
 	}
 	self->chip_id = self->chip_id_base + chip_id_offset;
-	chip_id = g_strdup_printf("SYNAPTICS_CXAUDIO\\CX%u", self->chip_id);
-	fu_device_add_instance_id(device, chip_id);
+	chip_id = g_strdup_printf("SYNAPTICS_CXAUDIO\\ID_CX%u", self->chip_id);
+	fu_device_add_instance_id_full(device, chip_id, FU_DEVICE_INSTANCE_FLAG_ONLY_QUIRKS);
 
 	/* set summary */
 	summary = g_strdup_printf("CX%u USB audio device", self->chip_id);
@@ -856,6 +856,7 @@ fu_synaptics_cxaudio_device_init(FuSynapticsCxaudioDevice *self)
 	self->sw_reset_supported = TRUE;
 	fu_device_add_icon(FU_DEVICE(self), "audio-card");
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
+	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
 	fu_device_set_version_format(FU_DEVICE(self), FWUPD_VERSION_FORMAT_PLAIN);
 	fu_device_set_install_duration(FU_DEVICE(self), 3); /* seconds */
 	fu_device_add_protocol(FU_DEVICE(self), "com.synaptics.cxaudio");
