@@ -7,11 +7,16 @@
 
 #pragma once
 
-#include "fu-srec-firmware.h"
+#include <fwupdplugin.h>
+
 #include "fu-synaptics-cxaudio-common.h"
 
-#define FU_TYPE_SYNAPTICS_CXAUDIO_FIRMWARE (fu_synaptics_cxaudio_firmware_get_type ())
-G_DECLARE_FINAL_TYPE (FuSynapticsCxaudioFirmware, fu_synaptics_cxaudio_firmware, FU, SYNAPTICS_CXAUDIO_FIRMWARE, FuSrecFirmware)
+#define FU_TYPE_SYNAPTICS_CXAUDIO_FIRMWARE (fu_synaptics_cxaudio_firmware_get_type())
+G_DECLARE_FINAL_TYPE(FuSynapticsCxaudioFirmware,
+		     fu_synaptics_cxaudio_firmware,
+		     FU,
+		     SYNAPTICS_CXAUDIO_FIRMWARE,
+		     FuSrecFirmware)
 
 typedef enum {
 	FU_SYNAPTICS_CXAUDIO_FILE_KIND_UNKNOWN,
@@ -26,7 +31,11 @@ typedef enum {
 	FU_SYNAPTICS_CXAUDIO_FILE_KIND_LAST
 } FuSynapticsCxaudioFileKind;
 
-FuFirmware			*fu_synaptics_cxaudio_firmware_new			(void);
-FuSynapticsCxaudioFileKind	 fu_synaptics_cxaudio_firmware_get_file_type		(FuSynapticsCxaudioFirmware	*self);
-FuSynapticsCxaudioDeviceKind	 fu_synaptics_cxaudio_firmware_get_devtype		(FuSynapticsCxaudioFirmware	*self);
-guint8				 fu_synaptics_cxaudio_firmware_get_layout_version	(FuSynapticsCxaudioFirmware	*self);
+FuFirmware *
+fu_synaptics_cxaudio_firmware_new(void);
+FuSynapticsCxaudioFileKind
+fu_synaptics_cxaudio_firmware_get_file_type(FuSynapticsCxaudioFirmware *self);
+FuSynapticsCxaudioDeviceKind
+fu_synaptics_cxaudio_firmware_get_devtype(FuSynapticsCxaudioFirmware *self);
+guint8
+fu_synaptics_cxaudio_firmware_get_layout_version(FuSynapticsCxaudioFirmware *self);
