@@ -133,16 +133,28 @@ fu_system76_launch_device_detach(FuDevice *device, FuProgress *progress, GError
 		return FALSE;
 
 	/* unlikely, but already unlocked */
-	if (rc == 0)
+	if (rc == 0) {
+		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
 		return TRUE;
+	}
 
 	/* generate a message if not already set */
 	if (fu_device_get_update_message(device) == NULL) {
 		g_autofree gchar *msg = NULL;
+		const gchar *unlock_keys;
+		switch (fu_usb_device_get_pid(FU_USB_DEVICE(device))) {
+		case 0x0001: /* launch_1 */
+			unlock_keys = "Fn+Esc";
+			break;
+		default:
+			unlock_keys = "Left Ctrl+Right Ctrl+Esc";
+			break;
+		}
 		msg = g_strdup_printf(
 		    "To ensure you have physical access, %s needs to be manually unlocked. "
-		    "Please press Fn+Esc to unlock and re-run the update.",
-		    fu_device_get_name(device));
+		    "Please press %s to unlock and re-run the update.",
+		    fu_device_get_name(device),
+		    unlock_keys);
 		fu_device_set_update_message(device, msg);
 	}
 
@@ -188,6 +200,7 @@ fu_system76_launch_device_init(FuSystem76LaunchDevice *self)
 	fu_device_set_remove_delay(FU_DEVICE(self), FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_ADD_COUNTERPART_GUIDS);
+	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
 	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID);
 	fu_device_set_version_format(FU_DEVICE(self), FWUPD_VERSION_FORMAT_PLAIN);
 	fu_device_add_protocol(FU_DEVICE(self), "org.usb.dfu");
