@@ -13,6 +13,10 @@
 #include "fu-thunderbolt-firmware.h"
 #include "fu-thunderbolt-retimer.h"
 
+/*5 seconds sleep until retimer is available                                       \
+				     after nvm update*/
+#define FU_THUNDERBOLT_RETIMER_CLEANUP_DELAY 5000000
+
 static gboolean
 fu_plugin_thunderbolt_safe_kernel(FuPlugin *plugin, GError **error)
 {
@@ -89,6 +93,7 @@ fu_plugin_thunderbolt_composite_cleanup(FuPlugin *plugin, GPtrArray *devices, GE
 		FuDevice *dev = g_ptr_array_index(devices, i);
 		if ((g_strcmp0(fu_device_get_plugin(dev), "thunderbolt") == 0) &&
 		    fu_device_has_internal_flag(dev, FU_DEVICE_INTERNAL_FLAG_NO_AUTO_REMOVE)) {
+			g_usleep(FU_THUNDERBOLT_RETIMER_CLEANUP_DELAY);
 			return fu_thunderbolt_retimer_set_parent_port_online(dev, error);
 		}
 	}
