@@ -30,13 +30,14 @@ typedef struct {
 	guint64 fmp_hardware_instance;
 	gboolean missing_header;
 	gboolean automounted_esp;
-	gboolean requires_header;
 } FuUefiDevicePrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE(FuUefiDevice, fu_uefi_device, FU_TYPE_DEVICE)
 
 #define GET_PRIVATE(o) (fu_uefi_device_get_instance_private(o))
 
+#define FU_EFI_FMP_CAPSULE_GUID "6dcbd5ed-e82d-4c44-bda1-7194199ad92a"
+
 enum {
 	PROP_0,
 	PROP_FW_CLASS,
@@ -416,10 +417,10 @@ fu_uefi_device_fixup_firmware(FuUefiDevice *self, GBytes *fw, GError **error)
 	if (g_strcmp0(fu_uefi_device_get_guid(self), guid_new) == 0) {
 		g_debug("ESRT matches payload GUID");
 		return g_bytes_ref(fw);
-		/* Type that doesn't require a header */
-	} else if (!priv->requires_header) {
+	} else if (g_strcmp0(guid_new, FU_EFI_FMP_CAPSULE_GUID) == 0 ||
+		   fu_device_has_private_flag(FU_DEVICE(self),
+					      FU_UEFI_DEVICE_FLAG_NO_CAPSULE_HEADER_FIXUP)) {
 		return g_bytes_ref(fw);
-		/* Missing, add a header */
 	} else {
 		guint header_size = getpagesize();
 		guint8 *new_data = g_malloc(fw_length + header_size);
@@ -597,8 +598,6 @@ fu_uefi_device_probe(FuDevice *device, GError **error)
 	FuUefiDevice *self = FU_UEFI_DEVICE(device);
 	FuUefiDevicePrivate *priv = GET_PRIVATE(self);
 	FwupdVersionFormat version_format;
-	g_autofree gchar *devid = NULL;
-	g_autofree gchar *guid_strup = NULL;
 	g_autofree gchar *version_lowest = NULL;
 	g_autofree gchar *version = NULL;
 
@@ -658,15 +657,9 @@ fu_uefi_device_probe(FuDevice *device, GError **error)
 	/* whether to create a missing header */
 	if (priv->kind == FU_UEFI_DEVICE_KIND_FMP ||
 	    priv->kind == FU_UEFI_DEVICE_KIND_DELL_TPM_FIRMWARE)
-		priv->requires_header = FALSE;
-	else
-		priv->requires_header = TRUE;
+		fu_device_add_private_flag(device, FU_UEFI_DEVICE_FLAG_NO_CAPSULE_HEADER_FIXUP);
 
-	/* Windows seems to be case insensitive, but for convenience we'll
-	 * match the upper case values typically specified in the .inf file */
-	guid_strup = g_ascii_strup(priv->fw_class, -1);
-	devid = g_strdup_printf("UEFI\\RES_{%s}", guid_strup);
-	fu_device_add_instance_id(device, devid);
+	/* success */
 	return TRUE;
 }
 
@@ -739,6 +732,7 @@ fu_uefi_device_init(FuUefiDevice *self)
 {
 	fu_device_set_summary(FU_DEVICE(self), "UEFI ESRT device");
 	fu_device_add_protocol(FU_DEVICE(self), "org.uefi.capsule");
+	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_MD_SET_SIGNED);
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_UEFI_DEVICE_FLAG_NO_UX_CAPSULE,
 					"no-ux-capsule");
@@ -760,6 +754,9 @@ fu_uefi_device_init(FuUefiDevice *self)
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_UEFI_DEVICE_FLAG_NO_RT_SET_VARIABLE,
 					"no-rt-set-variable");
+	fu_device_register_private_flag(FU_DEVICE(self),
+					FU_UEFI_DEVICE_FLAG_NO_CAPSULE_HEADER_FIXUP,
+					"no-capsule-header-fixup");
 }
 
 static void
