@@ -657,6 +657,12 @@ fu_device_list_replace(FuDeviceList *self, FuDeviceItem *item, FuDevice *device)
 		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_ANOTHER_WRITE_REQUIRED);
 	}
 
+	/* seems like a sane assumption if we've tagged the runtime mode as signed */
+	if (fu_device_has_flag(item->device, FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD))
+		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD);
+	if (fu_device_has_flag(item->device, FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD))
+		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
+
 	/* device won't come back in right mode */
 	if (fu_device_has_flag(item->device, FWUPD_DEVICE_FLAG_WILL_DISAPPEAR)) {
 		g_debug("copying will-disappear to new device");
@@ -725,6 +731,7 @@ fu_device_list_add(FuDeviceList *self, FuDevice *device)
 		if (g_strcmp0(fu_device_get_id(device), fu_device_get_id(item->device)) == 0) {
 			g_debug("found existing device %s", fu_device_get_id(device));
 			if (device != item->device) {
+				fu_device_uninhibit(item->device, "unconnected");
 				fu_device_incorporate_update_state(device, item->device);
 				fu_device_list_item_set_device(item, device);
 			}
@@ -737,6 +744,7 @@ fu_device_list_add(FuDeviceList *self, FuDevice *device)
 		if (item->device_old != NULL &&
 		    g_strcmp0(fu_device_get_id(device), fu_device_get_id(item->device_old)) == 0) {
 			g_debug("found old device %s, swapping", fu_device_get_id(device));
+			fu_device_uninhibit(item->device, "unconnected");
 			fu_device_incorporate_update_state(device, item->device);
 			g_set_object(&item->device_old, item->device);
 			fu_device_list_item_set_device(item, device);
