@@ -52,6 +52,12 @@ void
 fu_engine_request_set_locale(FuEngineRequest *self, const gchar *locale)
 {
 	g_return_if_fail(FU_IS_ENGINE_REQUEST(self));
+
+	/* not changed */
+	if (g_strcmp0(self->locale, locale) == 0)
+		return;
+
+	g_free(self->locale);
 	self->locale = g_strdup(locale);
 
 	/* remove the UTF8 suffix as it is not present in the XML */
@@ -94,9 +100,19 @@ fu_engine_request_init(FuEngineRequest *self)
 	self->feature_flags = FWUPD_FEATURE_FLAG_NONE;
 }
 
+static void
+fu_engine_request_finalize(GObject *obj)
+{
+	FuEngineRequest *self = FU_ENGINE_REQUEST(obj);
+	g_free(self->locale);
+	G_OBJECT_CLASS(fu_engine_request_parent_class)->finalize(obj);
+}
+
 static void
 fu_engine_request_class_init(FuEngineRequestClass *klass)
 {
+	GObjectClass *object_class = G_OBJECT_CLASS(klass);
+	object_class->finalize = fu_engine_request_finalize;
 }
 
 FuEngineRequest *
