@@ -68,7 +68,12 @@ fu_util_using_correct_daemon(GError **error)
 #ifdef HAVE_SYSTEMD
 	g_autofree gchar *default_target = NULL;
 	g_autoptr(GError) error_local = NULL;
-	const gchar *target = fu_util_get_systemd_unit();
+	const gchar *target;
+
+	if (g_getenv("FWUPD_DBUS_SOCKET") != NULL)
+		return TRUE;
+
+	target = fu_util_get_systemd_unit();
 
 	default_target = fu_systemd_get_default_target(&error_local);
 	if (default_target == NULL) {
@@ -384,7 +389,7 @@ fu_util_get_release_description_with_fallback(FwupdRelease *rel)
 		g_string_append(str, fwupd_release_get_description(rel));
 
 	/* add this client side to get the translations */
-	if (!fwupd_release_has_flag(rel, FWUPD_RELEASE_FLAG_IS_COMMUNITY)) {
+	if (fwupd_release_has_flag(rel, FWUPD_RELEASE_FLAG_IS_COMMUNITY)) {
 		g_string_append_printf(
 		    str,
 		    "<p>%s</p>",
@@ -779,6 +784,16 @@ fu_util_release_get_name(FwupdRelease *release)
 			 * PCI card, not the logical wired connection */
 			return g_strdup_printf(_("%s Network Interface Update"), name);
 		}
+		if (g_strcmp0(cat, "X-VideoDisplay") == 0) {
+			/* TRANSLATORS: Video Display refers to the laptop internal display or
+			 * external monitor */
+			return g_strdup_printf(_("%s Display Update"), name);
+		}
+		if (g_strcmp0(cat, "X-BaseboardManagementController") == 0) {
+			/* TRANSLATORS: BMC refers to baseboard management controller which
+			 * is the device that updates all the other firmware on the system */
+			return g_strdup_printf(_("%s BMC Update"), name);
+		}
 	}
 
 	/* TRANSLATORS: this is the fallback where we don't know if the release
@@ -1242,6 +1257,14 @@ fu_util_device_flag_to_string(guint64 device_flag)
 		/* TRANSLATORS: the vendor is no longer supporting the device */
 		return _("End of life");
 	}
+	if (device_flag == FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD) {
+		/* TRANSLATORS: firmware is verified on-device the payload using strong crypto */
+		return _("Signed Payload");
+	}
+	if (device_flag == FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD) {
+		/* TRANSLATORS: firmware payload is unsigned and it is possible to modify it */
+		return _("Unsigned Payload");
+	}
 	if (device_flag == FWUPD_DEVICE_FLAG_SKIPS_RESTART) {
 		/* skip */
 		return NULL;
@@ -1283,6 +1306,7 @@ fu_util_device_to_string(FwupdDevice *dev, guint idt)
 {
 	FwupdUpdateState state;
 	GPtrArray *guids = fwupd_device_get_guids(dev);
+	GPtrArray *issues = fwupd_device_get_issues(dev);
 	GPtrArray *vendor_ids = fwupd_device_get_vendor_ids(dev);
 	GPtrArray *instance_ids = fwupd_device_get_instance_ids(dev);
 	const gchar *tmp;
@@ -1496,6 +1520,14 @@ fu_util_device_to_string(FwupdDevice *dev, guint idt)
 			fu_common_string_append_kv(str, idt + 1, "", bullet);
 		}
 	}
+	for (guint i = 0; i < issues->len; i++) {
+		const gchar *issue = g_ptr_array_index(issues, i);
+		fu_common_string_append_kv(str,
+					   idt + 1,
+					   /* TRANSLATORS: issue fixed with the release, e.g. CVE */
+					   i == 0 ? ngettext("Issue", "Issues", issues->len) : "",
+					   issue);
+	}
 
 	return g_string_free(g_steal_pointer(&str), FALSE);
 }
@@ -1605,7 +1637,7 @@ fu_util_plugin_to_string(FwupdPlugin *plugin, guint idt)
 	/* TRANSLATORS: description of plugin state, e.g. disabled */
 	hdr = _("Flags");
 	if (flags == 0x0) {
-		const gchar *tmp = fu_util_plugin_flag_to_cli_text(flags);
+		g_autofree gchar *tmp = fu_util_plugin_flag_to_cli_text(flags);
 		g_autofree gchar *li = g_strdup_printf("• %s", tmp);
 		fu_common_string_append_kv(str, idt + 1, hdr, li);
 	} else {
@@ -2053,100 +2085,106 @@ fu_security_attr_append_str(FwupdSecurityAttr *attr,
 static gchar *
 fu_util_security_event_to_string(FwupdSecurityAttr *attr)
 {
+	g_autofree gchar *name = NULL;
 	struct {
 		const gchar *appstream_id;
 		FwupdSecurityAttrResult result_old;
 		FwupdSecurityAttrResult result_new;
 		const gchar *text;
-	} items[] = {{"org.fwupd.hsi.Iommu",
+	} items[] = {{FWUPD_SECURITY_ATTR_ID_IOMMU,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_FOUND,
 		      FWUPD_SECURITY_ATTR_RESULT_ENABLED,
 		      /* TRANSLATORS: HSI event title */
 		      _("IOMMU device protection enabled")},
-		     {"org.fwupd.hsi.Iommu",
+		     {FWUPD_SECURITY_ATTR_ID_IOMMU,
 		      FWUPD_SECURITY_ATTR_RESULT_ENABLED,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_FOUND,
 		      /* TRANSLATORS: HSI event title */
 		      _("IOMMU device protection disabled")},
 		     /* ------------------------------------------*/
-		     {"org.fwupd.hsi.Fwupd.Plugins",
+		     {FWUPD_SECURITY_ATTR_ID_FWUPD_PLUGINS,
 		      FWUPD_SECURITY_ATTR_RESULT_TAINTED,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_TAINTED,
 		      NULL},
-		     {"org.fwupd.hsi.Fwupd.Plugins",
+		     {FWUPD_SECURITY_ATTR_ID_FWUPD_PLUGINS,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_TAINTED,
 		      FWUPD_SECURITY_ATTR_RESULT_TAINTED,
 		      NULL},
-		     {"org.fwupd.hsi.Fwupd.Plugins",
+		     {FWUPD_SECURITY_ATTR_ID_FWUPD_PLUGINS,
 		      FWUPD_SECURITY_ATTR_RESULT_UNKNOWN,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_ENABLED,
 		      NULL},
 		     /* ------------------------------------------*/
-		     {"org.fwupd.hsi.Kernel.Tainted",
+		     {FWUPD_SECURITY_ATTR_ID_KERNEL_TAINTED,
 		      FWUPD_SECURITY_ATTR_RESULT_TAINTED,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_TAINTED,
 		      /* TRANSLATORS: HSI event title */
 		      _("Kernel is tainted")},
-		     {"org.fwupd.hsi.Kernel.Tainted",
+		     {FWUPD_SECURITY_ATTR_ID_KERNEL_TAINTED,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_TAINTED,
 		      FWUPD_SECURITY_ATTR_RESULT_TAINTED,
 		      /* TRANSLATORS: HSI event title */
 		      _("Kernel is no longer tainted")},
 		     /* ------------------------------------------*/
-		     {"org.fwupd.hsi.Kernel.Lockdown",
+		     {FWUPD_SECURITY_ATTR_ID_KERNEL_LOCKDOWN,
 		      FWUPD_SECURITY_ATTR_RESULT_ENABLED,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_ENABLED,
 		      /* TRANSLATORS: HSI event title */
 		      _("Kernel lockdown disabled")},
-		     {"org.fwupd.hsi.Kernel.Lockdown",
+		     {FWUPD_SECURITY_ATTR_ID_KERNEL_LOCKDOWN,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_ENABLED,
 		      FWUPD_SECURITY_ATTR_RESULT_ENABLED,
 		      /* TRANSLATORS: HSI event title */
 		      _("Kernel lockdown enabled")},
 		     /* ------------------------------------------*/
-		     {"org.fwupd.hsi.AcpiDmar",
+		     {FWUPD_SECURITY_ATTR_ID_ACPI_DMAR,
 		      FWUPD_SECURITY_ATTR_RESULT_ENABLED,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_ENABLED,
 		      /* TRANSLATORS: HSI event title */
 		      _("Pre-boot DMA protection is disabled")},
-		     {"org.fwupd.hsi.AcpiDmar",
+		     {FWUPD_SECURITY_ATTR_ID_ACPI_DMAR,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_ENABLED,
 		      FWUPD_SECURITY_ATTR_RESULT_ENABLED,
 		      /* TRANSLATORS: HSI event title */
 		      _("Pre-boot DMA protection is enabled")},
 		     /* ------------------------------------------*/
-		     {"org.fwupd.hsi.Uefi.SecureBoot",
+		     {FWUPD_SECURITY_ATTR_ID_UEFI_SECUREBOOT,
 		      FWUPD_SECURITY_ATTR_RESULT_ENABLED,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_ENABLED,
 		      /* TRANSLATORS: HSI event title */
 		      _("Secure Boot disabled")},
-		     {"org.fwupd.hsi.Uefi.SecureBoot",
+		     {FWUPD_SECURITY_ATTR_ID_UEFI_SECUREBOOT,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_ENABLED,
 		      FWUPD_SECURITY_ATTR_RESULT_ENABLED,
 		      /* TRANSLATORS: HSI event title */
 		      _("Secure Boot enabled")},
 		     /* ------------------------------------------*/
-		     {"org.fwupd.hsi.Tpm.EmptyPcr",
+		     {FWUPD_SECURITY_ATTR_ID_TPM_EMPTY_PCR,
 		      FWUPD_SECURITY_ATTR_RESULT_UNKNOWN,
 		      FWUPD_SECURITY_ATTR_RESULT_VALID,
 		      /* TRANSLATORS: HSI event title */
 		      _("All TPM PCRs are valid")},
-		     {"org.fwupd.hsi.Tpm.EmptyPcr",
+		     {FWUPD_SECURITY_ATTR_ID_TPM_EMPTY_PCR,
 		      FWUPD_SECURITY_ATTR_RESULT_VALID,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_VALID,
 		      /* TRANSLATORS: HSI event title */
-		      _("All TPM PCRs are now valid")},
-		     {"org.fwupd.hsi.Uefi.SecureBoot",
-		      FWUPD_SECURITY_ATTR_RESULT_NOT_VALID,
-		      FWUPD_SECURITY_ATTR_RESULT_VALID,
-		      /* TRANSLATORS: HSI event title */
 		      _("A TPM PCR is now an invalid value")},
+		     {FWUPD_SECURITY_ATTR_ID_TPM_EMPTY_PCR,
+		      FWUPD_SECURITY_ATTR_RESULT_NOT_VALID,
+		      FWUPD_SECURITY_ATTR_RESULT_VALID,
+		      /* TRANSLATORS: HSI event title */
+		      _("All TPM PCRs are now valid")},
 		     /* ------------------------------------------*/
-		     {"org.fwupd.hsi.Tpm.ReconstructionPcr0",
+		     {FWUPD_SECURITY_ATTR_ID_TPM_RECONSTRUCTION_PCR0,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_FOUND,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_VALID,
 		      /* TRANSLATORS: HSI event title */
 		      _("TPM PCR0 reconstruction is invalid")},
+		     {FWUPD_SECURITY_ATTR_ID_TPM_RECONSTRUCTION_PCR0,
+		      FWUPD_SECURITY_ATTR_RESULT_NOT_VALID,
+		      FWUPD_SECURITY_ATTR_RESULT_VALID,
+		      /* TRANSLATORS: HSI event title */
+		      _("TPM PCR0 reconstruction is now valid")},
 		     {NULL, 0, 0, NULL}};
 
 	/* sanity check */
@@ -2167,31 +2205,34 @@ fu_util_security_event_to_string(FwupdSecurityAttr *attr)
 
 	/* disappeared */
 	if (fwupd_security_attr_get_result(attr) == FWUPD_SECURITY_ATTR_RESULT_UNKNOWN) {
+		name = fu_security_attr_get_name(attr);
 		return g_strdup_printf(
 		    /* TRANSLATORS: %1 refers to some kind of security test, e.g. "SPI BIOS region".
 		       %2 refers to a result value, e.g. "Invalid" */
 		    _("%s disappeared: %s"),
-		    fu_security_attr_get_name(attr),
+		    name,
 		    fu_security_attr_result_to_string(
 			fwupd_security_attr_get_result_fallback(attr)));
 	}
 
 	/* appeared */
 	if (fwupd_security_attr_get_result_fallback(attr) == FWUPD_SECURITY_ATTR_RESULT_UNKNOWN) {
+		name = fu_security_attr_get_name(attr);
 		return g_strdup_printf(
 		    /* TRANSLATORS: %1 refers to some kind of security test, e.g. "Encrypted RAM".
 		       %2 refers to a result value, e.g. "Invalid" */
 		    _("%s appeared: %s"),
-		    fu_security_attr_get_name(attr),
+		    name,
 		    fu_security_attr_result_to_string(fwupd_security_attr_get_result(attr)));
 	}
 
 	/* fall back to something sensible */
+	name = fu_security_attr_get_name(attr);
 	return g_strdup_printf(
 	    /* TRANSLATORS: %1 refers to some kind of security test, e.g. "UEFI platform key".
 	     * %2 and %3 refer to results value, e.g. "Valid" and "Invalid" */
 	    _("%s changed: %s → %s"),
-	    fu_security_attr_get_name(attr),
+	    name,
 	    fu_security_attr_result_to_string(fwupd_security_attr_get_result_fallback(attr)),
 	    fu_security_attr_result_to_string(fwupd_security_attr_get_result(attr)));
 }
@@ -2242,6 +2283,41 @@ fu_util_security_events_to_string(GPtrArray *events, FuSecurityAttrToStringFlags
 	return g_string_free(g_steal_pointer(&str), FALSE);
 }
 
+gchar *
+fu_util_security_issues_to_string(GPtrArray *devices)
+{
+	g_autoptr(GString) str = g_string_new(NULL);
+
+	for (guint i = 0; i < devices->len; i++) {
+		FwupdDevice *device = g_ptr_array_index(devices, i);
+		GPtrArray *issues = fwupd_device_get_issues(device);
+		if (issues->len == 0)
+			continue;
+		if (str->len == 0) {
+			g_string_append_printf(
+			    str,
+			    "%s\n",
+			    /* TRANSLATORS: now list devices with unfixed high-priority issues */
+			    _("There are devices with issues:"));
+		}
+		g_string_append_printf(str,
+				       "\n  %s — %s:\n",
+				       fwupd_device_get_vendor(device),
+				       fwupd_device_get_name(device));
+		for (guint j = 0; j < issues->len; j++) {
+			const gchar *issue = g_ptr_array_index(issues, j);
+			g_string_append_printf(str, "   • %s\n", issue);
+		}
+	}
+
+	/* no output required */
+	if (str->len == 0)
+		return NULL;
+
+	/* success */
+	return g_string_free(g_steal_pointer(&str), FALSE);
+}
+
 gchar *
 fu_util_security_attrs_to_string(GPtrArray *attrs, FuSecurityAttrToStringFlags strflags)
 {
@@ -2526,6 +2602,7 @@ fu_util_switch_branch_warning(FwupdDevice *dev,
 gboolean
 fu_util_prompt_warning_fde(FwupdDevice *dev, GError **error)
 {
+	const gchar *url = "https://github.com/fwupd/fwupd/wiki/Full-Disk-Encryption-Detected";
 	g_autoptr(GString) str = g_string_new(NULL);
 
 	if (!fwupd_device_has_flag(dev, FWUPD_DEVICE_FLAG_AFFECTS_FDE))
@@ -2540,6 +2617,11 @@ fu_util_prompt_warning_fde(FwupdDevice *dev, GError **error)
 			/* TRANSLATORS: 'recovery key' here refers to a code, rather than a physical
 			   metal thing */
 			_("Please ensure you have the volume recovery key before continuing."));
+	g_string_append(str, "\n\n");
+	g_string_append_printf(str,
+			       /* TRANSLATORS: the %1 is a URL to a wiki page */
+			       _("See %s for more details."),
+			       url);
 	/* TRANSLATORS: title text, shown as a warning */
 	fu_util_warning_box(_("Full Disk Encryption Detected"), str->str, 80);
 
